@@ -1,3 +1,4 @@
+{-# LANGUAGE CPP                #-}
 {-# LANGUAGE NamedFieldPuns     #-}
 module Tests.Reference (
     testTree
@@ -16,6 +17,9 @@ import qualified Data.Text.Encoding as T
 import qualified Data.Vector as V
 import           Data.Scientific (fromFloatDigits, toRealFloat)
 import           Data.Aeson as Aeson
+#if MIN_VERSION_aeson(2,0,0)
+import           Data.Aeson.Key as Aeson.Key
+#endif
 import           Data.Word
 import qualified Numeric.Half as Half
 
@@ -68,6 +72,13 @@ equalJson (Aeson.Number expected) (Aeson.Number actual)
 
 equalJson expected actual = expected @=? actual
 
+#if MIN_VERSION_aeson(2,0,0)
+stringToJsonKey :: String -> Aeson.Key.Key
+stringToJsonKey = Aeson.Key.fromString
+#else
+stringToJsonKey :: String -> T.Text
+stringToJsonKey = T.pack
+#endif
 
 termToJson :: CBOR.Term -> Aeson.Value
 termToJson (TUInt    n)   = Aeson.Number (fromIntegral (fromUInt n))
@@ -79,9 +90,9 @@ termToJson (TString  cs)  = Aeson.String (T.pack cs)
 termToJson (TStrings css) = Aeson.String (T.pack (concat css))
 termToJson (TArray   ts)  = Aeson.Array  (V.fromList (map termToJson ts))
 termToJson (TArrayI  ts)  = Aeson.Array  (V.fromList (map termToJson ts))
-termToJson (TMap     kvs) = Aeson.object [ (T.pack k, termToJson v)
+termToJson (TMap     kvs) = Aeson.object [ (stringToJsonKey k, termToJson v)
                                          | (TString k,v) <- kvs ]
-termToJson (TMapI    kvs) = Aeson.object [ (T.pack k, termToJson v)
+termToJson (TMapI    kvs) = Aeson.object [ (stringToJsonKey k, termToJson v)
                                          | (TString k,v) <- kvs ]
 termToJson (TTagged _ t)  = termToJson t
 termToJson  TTrue         = Aeson.Bool True
